==> zbxe.beta.0.1.2.tgz: zbxe/common/lang/es.lang.php <==
<?php
    /**
     * @archivo   common/lang/es.lang.php
     * @autor zero (zero@nzeo.com)
     * @sumario Paquete del Idioma Español (incluye sólo las palabras básicas )
     **/

    // palabras para la acción, las cuales son basicamente usados
    $lang->cmd_write = 'Escribir';
    $lang->cmd_reply = 'Respuesta';
    $lang->cmd_delete = 'Borrar';
    $lang->cmd_modify = 'Modificar';
    $lang->cmd_edit = 'editar';
    $lang->cmd_view = 'Ver';
    $lang->cmd_view_all = 'Ver todo';
    $lang->cmd_list = 'Lista';
    $lang->cmd_prev = 'Anterior';
    $lang->cmd_next = 'Siguiente';
    $lang->cmd_send_trackback = 'Enviar Trackback';
    $lang->cmd_registration = $lang->cmd_submit = 'Enviar';
    $lang->cmd_comment_registration = 'Agregar el commentario';
    $lang->cmd_insert = 'Insertar';
    $lang->cmd_save = 'Guardar';
    $lang->cmd_input = 'Ingresar';
    $lang->cmd_search = 'Buscar';
    $lang->cmd_cancel = 'Cancelar';
    $lang->cmd_back = 'Atrás';
    $lang->cmd_vote = 'Recomendar';
    $lang->cmd_move = 'Mover';
    $lang->cmd_move_up = 'Arriba';
    $lang->cmd_move_down = 'Abajo';
    $lang->cmd_add_indent = 'Agregar';
    $lang->cmd_remove_indent = 'Eliminar';
    $lang->cmd_management = 'Administración';
    $lang->cmd_make = 'Crear';
    $lang->cmd_select = 'Seleccionar';
    $lang->cmd_select_all = 'Seleccionar todo';
    $lang->cmd_unselect_all = 'Cancelar todo';
    $lang->cmd_close_all = 'Cerrar todo';
    $lang->cmd_open_all = 'Abrir todo';
    $lang->cmd_reload = 'Actualizar';
    $lang->cmd_close = 'Cerrar';
    $lang->cmd_open = 'Abrir';
    $lang->cmd_setup = 'Configuración';
	$lang->cmd_option = 'Opción';
    $lang->cmd_apply = 'Aplicar';
    $lang->cmd_open_calendar = 'Abrir el calendario';
    $lang->cmd_send = 'Enviar';
    $lang->cmd_print = 'Imprimir';
    $lang->cmd_scrap = 'Scrap';
    $lang->cmd_preview = 'Previo';
    $lang->cmd_reset = 'Rehacer';

    $lang->enable = 'Activar';
    $lang->disable = 'Desactivar';

    // Palabras Esenciales
    $lang->no = 'No';
    $lang->notice = 'Aviso';
    $lang->secret = 'Secreto';
    $lang->category = 'Categoría';
    $lang->document_srl = 'Núm.Mensaje';
    $lang->user_id = 'Usuario';
    $lang->author = 'Autor';
    $lang->password = 'Contraseña';
    $lang->password1 = 'Contraseña';
    $lang->password2 = 'Confirmar la contraseña';
    $lang->admin_id = 'Identificación del Administrador';
    $lang->writer = 'Autor';
    $lang->user_name = 'Nombre De Usuario';
    $lang->nick_name = 'Apodo';
    $lang->email_address = 'Correo electrónico';
    $lang->homepage = 'Página web';
    $lang->blog = 'Blog';
    $lang->birthday = 'Fecha de Nacimiento';
    $lang->browser_title = 'Título del navegador';
    $lang->title = 'Título';
    $lang->title_content = 'Título+Contenido';
    $lang->content = 'Contenido';
    $lang->document = 'Mensaje';
    $lang->comment = 'Commentario';
    $lang->description = 'Descripción';
    $lang->trackback = 'Trackback';
    $lang->tag = 'Etiqueta';
    $lang->allow_comment = 'Permitir Commentarios';
    $lang->lock_comment = 'Bloquear Commentarios';
    $lang->allow_trackback = 'Permitir Trackback';
    $lang->uploaded_file = 'Archivos Ajuntos';
    $lang->grant = 'Atribución';
    $lang->target = 'Objetivo';
    $lang->total = 'Total';
    $lang->total_count = 'Núm.Total';
    $lang->ipaddress = 'Dirección IP';
    $lang->path = 'Paso';
    $lang->cart = 'Artículo Seleccionado';
    $lang->friend = 'Amigos';
    $lang->notify = 'Notificación';

    $lang->mid = 'Nombre del Módulo';
    $lang->layout = 'Diseño';
    $lang->widget = 'Herramienta';
    $lang->module = 'Módulo';
    $lang->skin = 'Tema';
    $lang->colorset = 'Colores';
    $lang->extra_vars = 'Variables Extra';

    $lang->document_url = 'URL del Mensaje';
    $lang->trackback_url = 'URL del Trackback';
    $lang->blog_name = 'Titulo del Blog';
    $lang->excerpt = 'Extracción';

    $lang->document_count = 'Cantidad del Mensaje';
    $lang->page_count = 'Cantidad de la Página';
    $lang->list_count = 'Cantidad de la Lista';
    $lang->readed_count = 'Leídos';
    $lang->voted_count = 'Recomendados';
    $lang->member_count = 'Cantidad del Usuario';
    $lang->date = 'Fecha';
    $lang->regdate = 'Fecha Publicada';
    $lang->last_update = 'Última actualización';
    $lang->signup_date = 'Fecha del Registro';
    $lang->last_login = 'Última Conección';
    $lang->first_page = 'Primera Página';
    $lang->last_page = 'Última Página';
    $lang->search_target = 'Buscar Objectivo';
    $lang->search_keyword = 'Buscar la Palabra Clave';
    $lang->is_default = 'Prefijado';

    $lang->no_documents = 'Sin Mensajes';

    $lang->board_manager = 'Manejo de los Tableros';
    $lang->member_manager = 'MAnejo de los usuarios';
    $lang->layout_manager = 'MAnejo de los Diseños';

    $lang->use = 'Usar';
    $lang->notuse = 'No usar';
    $lang->not_exists = 'No existe';

    $lang->unit_sec = 'segundo';
    $lang->unit_min = 'minuto';
    $lang->unit_hour = 'hora';
    $lang->unit_day = 'día';
    $lang->unit_week = 'semana';
    $lang->unit_month = 'mes';
    $lang->unit_year = 'año';

    // Relacionado a la Descripción 
    $lang->about_tag = 'Tú puedes agregar múltiples etiquetas colocando una coma(,) entre cada etiqueta';
    $lang->about_layout = 'El diseño decora la apariencia de tus módulos, lo cual podrás configurar en el menú Diseño en la parte                           superior';

    // Relacionado al Mensaje
    $lang->msg_call_server = 'Solicitando al servidor, espere por favor';
    $lang->msg_db_not_setted = 'Configuración de DB no ha sido creado';
    $lang->msg_invalid_queryid = 'El valor de Query ID especificado es inválido';
    $lang->msg_not_permitted = 'Acceso denegado';
    $lang->msg_input_password = 'Coloque la contraseña';
    $lang->msg_invalid_document = 'Mensaje inválido';
    $lang->msg_invalid_request = 'Respuesta Inválida';
    $lang->msg_invalid_password = 'Contraseña Inválida';
    $lang->msg_error_occured = 'Error';
    $lang->msg_not_founded = 'No encontrado';
    $lang->msg_no_result = 'Sin resultados';

    $lang->msg_not_permitted_act = 'Usted no tiene permiso para ejecutar la action solicitada';
    $lang->msg_module_is_not_exists = 'Módulo solicitado no puede ser encontrado';
    $lang->msg_module_is_not_standalone = 'Módulo solicitado no puede ser ejecutado independientemente';

    $lang->success_registed = 'Registrado con éxito';
    $lang->success_updated = 'Actualizado con éxito';
    $lang->success_deleted = 'Boarrado con éxito';
    $lang->success_voted = 'Recomendado con éxito';
    $lang->success_moved = 'Movido con éxito';
    $lang->success_sended = 'Enviado con éxito';
    $lang->success_reset = 'Reajustado con éxito';
    $lang->success_leaved = 'Abandonó con éxito';

    $lang->fail_to_delete = 'No puede ser borrado';
    $lang->fail_to_move = 'No puede ser movido';

    $lang->failed_voted = 'No puede ser recomendado';
    $lang->fail_to_delete_have_children = 'No puede ser borrados, ya que el mensaje posee respuestas ';

    $lang->confirm_submit = 'Estás seguro que deseas enviar?';
    $lang->confirm_logout = 'Estás seguro que deseas desconectar?';
    $lang->confirm_vote = 'Estás seguro que deseas recomendar?';
    $lang->confirm_delete = 'Estás seguro que deseas borrar?';
    $lang->confirm_move = 'Estás seguro que deseas mover?';
    $lang->confirm_reset = 'Estás seguro que deseas rehacer?';
    $lang->confirm_leave = 'Estás seguro que deseas salir?';

    $lang->column_type = 'Tipos de Columnas';
    $lang->column_type_list['text'] = 'Texto de una linea';
    $lang->column_type_list['homepage'] = 'url';
    $lang->column_type_list['email_address'] = 'Correo Electrónico';
    $lang->column_type_list['tel'] = 'Número de teléfono';
    $lang->column_type_list['textarea'] = 'Texto multi-linea';
    $lang->column_type_list['checkbox'] = 'Cuadro de chequeo (selecciónes múltiples)';
    $lang->column_type_list['select'] = 'Cuadro de selección (selección individual)';
    //$lang->column_type_list['kr_zip'] = 'zip code (Korean)';
    $lang->column_type_list['date'] = 'fecha (dd/mm/aaaa)';
    //$lang->column_type_list['jp_zip'] = 'zip code (Japanese)';
    $lang->column_name = 'Nombre de la Columna';
    $lang->column_title = 'Título de la Columna';
    $lang->default_value = 'Valor Prefijado';
    $lang->is_active = 'Activado';
    $lang->is_required = 'Campo requerido';

    // Mensajes de alerta para Javascript usando el filtro XML
    $lang->filter->isnull = 'Por favor ingresar un valor para %s';
    $lang->filter->outofrange = 'Por favor alinear el largo del texto de %s';
    $lang->filter->equalto = 'Valor de %s es inválido.';
    $lang->filter->invalid_email = 'Formato de %s es inválido. (ej. zbxe@zeroboard.com)';
    $lang->filter->invalid_user_id = $lang->filter->invalid_userid = "Formato de %s es inválido.\\n Todos los valores deberá consistir en alfabetos, números o guión abajo(_) y la primera letra deberá ser el alfabeto Español";
    $lang->filter->invalid_homepage = 'Formato de %s es inválido. (ej: http://www.zeroboard.com)';
    $lang->filter->invalid_korean = 'Formato de %s es inválido. Por favor ingresar sólo coreano';
    $lang->filter->invalid_korean_number = 'Formato de %s es inválido. Por favor ingresar coreano o números';
    $lang->filter->invalid_alpha = 'Formato de %s es inválido. Por favor ingresar sólo alfabetos';
    $lang->filter->invalid_alpha_number = 'Formato de %s es inválido. Por favor ingresar alfabetos o números';
    $lang->filter->invalid_number = 'Formato de %s es inválido. Por favor ingresar sólo números.';
?>

==> zbxe.beta.0.1.4.tgz: zbxe/common/lang/es.lang.php <==
<?php
    /**
     * @archivo   common/lang/es.lang.php
     * @autor zero (zero@nzeo.com)
     * @sumario Paquete del Idioma Español (incluye sólo las palabras básicas )
     **/

    // palabras para la acción, las cuales son basicamente usados
    $lang->cmd_write = 'Escribir';
    $lang->cmd_reply = 'Responder';
    $lang->cmd_delete = 'Eliminar';
    $lang->cmd_modify = 'Modificar';
    $lang->cmd_edit = 'editar';
    $lang->cmd_view = 'Ver';
    $lang->cmd_view_all = 'Ver todo';
    $lang->cmd_list = 'Lista';
    $lang->cmd_prev = 'Anterior';
    $lang->cmd_next = 'Siguiente';
    $lang->cmd_send_trackback = 'Enviar Trackback';
    $lang->cmd_registration = $lang->cmd_submit = 'Enviar';
    $lang->cmd_comment_registration = 'Agregar commentarios';
    $lang->cmd_insert = 'Insertar';
    $lang->cmd_save = 'Guardar';
    $lang->cmd_input = 'Ingresar';
    $lang->cmd_search = 'Buscar';
    $lang->cmd_cancel = 'Cancelar';
    $lang->cmd_back = 'Atrás';
    $lang->cmd_vote = 'Recomendar';
    $lang->cmd_move = 'Mover';
    $lang->cmd_move_up = 'Arriba';
    $lang->cmd_move_down = 'Abajo';
    $lang->cmd_add_indent = 'Agregar';
    $lang->cmd_remove_indent = 'Eliminar';
    $lang->cmd_management = 'Administración';
    $lang->cmd_make = 'Crear';
    $lang->cmd_select = 'Seleccionar';
    $lang->cmd_select_all = 'Seleccionar todo';
    $lang->cmd_unselect_all = 'Cancelar todo';
    $lang->cmd_close_all = 'Cerrar todo';
    $lang->cmd_open_all = 'Abrir todo';
    $lang->cmd_reload = 'Actualizar';
    $lang->cmd_close = 'Cerrar';
    $lang->cmd_open = 'Abrir';
    $lang->cmd_setup = 'Configuración';
	$lang->cmd_option = 'Opción';
    $lang->cmd_apply = 'Aplicar';
    $lang->cmd_open_calendar = 'Abrir el calendario';
    $lang->cmd_send = 'Enviar';
    $lang->cmd_print = 'Imprimir';
    $lang->cmd_scrap = 'Scrap';
    $lang->cmd_preview = 'Previo';
    $lang->cmd_reset = 'Rehacer';

    $lang->enable = 'Activar';
    $lang->disable = 'Desactivar';

    // Palabras Esenciales
    $lang->no = 'Nº';
    $lang->notice = 'Aviso';
    $lang->secret = 'Secreto';
    $lang->category = 'Categoría';
    $lang->document_srl = 'Número del documento';
    $lang->user_id = 'Usuario';
    $lang->author = 'Autor';
    $lang->password = 'Contraseña';
    $lang->password1 = 'Contraseña';
    $lang->password2 = 'Confirmar la contraseña';
    $lang->admin_id = 'Identificación del Administrador';
    $lang->writer = 'Escritor';
    $lang->user_name = 'Nombre del Usuario';
    $lang->nick_name = 'Apodo';
    $lang->email_address = 'Correo electrónico';
    $lang->homepage = 'Página web';
    $lang->blog = 'Blog';
    $lang->birthday = 'Fecha de Nacimiento';
    $lang->browser_title = 'Título del navegador';
    $lang->title = 'Título';
    $lang->title_content = 'Título+Contenido';
    $lang->content = 'Contenidos';
    $lang->document = 'Documentos';
    $lang->comment = 'Commentarios';
    $lang->description = 'Descripción';
    $lang->trackback = 'Trackback';
    $lang->tag = 'Etiqueta';
    $lang->allow_comment = 'Permitir Commentarios';
    $lang->lock_comment = 'Bloquear Commentarios';
    $lang->allow_trackback = 'Permitir Trackback';
    $lang->uploaded_file = 'Archivos Adjuntos';
    $lang->grant = 'Atribución';
    $lang->target = 'Objetivo';
    $lang->total = 'Total';
    $lang->total_count = 'Número total';
    $lang->ipaddress = 'Dirección IP';
    $lang->path = 'Ruta';
    $lang->cart = 'Artículo Seleccionado';
    $lang->friend = 'Amigos';
    $lang->notify = 'Notificación';

    $lang->mid = 'Nombre del Módulo';
    $lang->layout = 'Diseño';
    $lang->widget = 'Widget';
    $lang->module = 'Módulo';
    $lang->skin = 'Tema';
    $lang->colorset = 'Set de colores';
    $lang->extra_vars = 'Variables Extra';

    $lang->document_url = 'URL del Documento';
    $lang->trackback_url = 'URL del Trackback';
    $lang->blog_name = 'Titulo del Blog';
    $lang->excerpt = 'Extracto';

    $lang->document_count = 'Cantidad de documentos';
    $lang->page_count = 'Cantidad de páginas';
    $lang->list_count = 'Cantidad de listas';
    $lang->readed_count = 'Leídos';
    $lang->voted_count = 'Recomendados';
    $lang->member_count = 'Cantidad de usuarios';
    $lang->date = 'Fecha';
    $lang->regdate = 'Fecha publicada';
    $lang->last_update = 'Ultima actualización';
    $lang->signup_date = 'Fecha del registro';
    $lang->last_login = 'Ultima conección';
    $lang->first_page = 'Primera página';
    $lang->last_page = 'Ultima página';
    $lang->search_target = 'Objectivo a buscar';
    $lang->search_keyword = 'Palabra a buscar';
    $lang->is_default = 'Predefinido';

    $lang->no_documents = 'Sin documentos';

    $lang->board_manager = 'Manejo de los Tableros';
    $lang->member_manager = 'MAnejo de los usuarios';
    $lang->layout_manager = 'MAnejo de los Diseños';

    $lang->use = 'Usar';
    $lang->notuse = 'No usar';
    $lang->not_exists = 'No existe';

    $lang->unit_sec = 'segundo';
    $lang->unit_min = 'minuto';
    $lang->unit_hour = 'hora';
    $lang->unit_day = 'día';
    $lang->unit_week = 'semana';
    $lang->unit_month = 'mes';
    $lang->unit_year = 'año';

    // Relacionado a la Descripción 
    $lang->about_tag = 'Tú puedes agregar múltiples etiquetas colocando una coma(,) entre cada etiqueta';
    $lang->about_layout = 'El diseño decora la apariencia de tus módulos, lo cual podrás configurar en el menú de Diseño en la parte                           superior';

    // Relacionado al Mensaje
    $lang->msg_call_server = 'Solicitando al servidor, espere un momento';
    $lang->msg_db_not_setted = 'Configuración de DB no ha sido creado';
    $lang->msg_invalid_queryid = 'El valor de Query ID especificado es inválido';
    $lang->msg_not_permitted = 'Acceso denegado';
    $lang->msg_input_password = 'Coloque la contraseña';
    $lang->msg_invalid_document = 'Mensaje inválido';
    $lang->msg_invalid_request = 'Respuesta Inválida';
    $lang->msg_invalid_password = 'Contraseña Inválida';
    $lang->msg_error_occured = 'Error';
    $lang->msg_not_founded = 'No puede ser encontrado';
    $lang->msg_no_result = 'Sin resultados';

    $lang->msg_not_permitted_act = 'Usted no tiene permiso para ejecutar la action solicitada';
    $lang->msg_module_is_not_exists = 'Módulo solicitado no puede ser encontrado';
    $lang->msg_module_is_not_standalone = 'Módulo solicitado no puede ser ejecutado independientemente';

    $lang->success_registed = 'Agregado con éxito';
    $lang->success_updated = 'Actualizado con éxito';
    $lang->success_deleted = 'Boarrado con éxito';
    $lang->success_voted = 'Recomendado con éxito';
    $lang->success_moved = 'Movido con éxito';
    $lang->success_sended = 'Enviado con éxito';
    $lang->success_reset = 'Reajustado con éxito';
    $lang->success_leaved = 'Abandonado con éxito';

    $lang->fail_to_delete = 'No puede ser borrado';
    $lang->fail_to_move = 'No puede ser movido';

    $lang->failed_voted = 'No puede ser recomendado';
    $lang->fail_to_delete_have_children = 'No puede ser borrado, ya que el mensaje posee respuestas ';

    $lang->confirm_submit = '¿Está seguro que desea enviar?';
    $lang->confirm_logout = '¿Está seguro que desea desconectar?';
    $lang->confirm_vote = '¿Está seguro que desea recomendar?';
    $lang->confirm_delete = '¿Está seguro que desea borrar?';
    $lang->confirm_move = '¿Está seguro que desea mover?';
    $lang->confirm_reset = '¿Está seguro que desea rehacer?';
    $lang->confirm_leave = '¿Está seguro que desea salir?';

    $lang->column_type = 'Tipos de Columnas';
    $lang->column_type_list['text'] = 'Texto de una linea';
    $lang->column_type_list['homepage'] = 'URL';
    $lang->column_type_list['email_address'] = 'Correo Electrónico';
    $lang->column_type_list['tel'] = 'Número de teléfono';
    $lang->column_type_list['textarea'] = 'Texto multi-linea';
    $lang->column_type_list['checkbox'] = 'Cuadro de chequeo (selecciónes múltiples)';
    $lang->column_type_list['select'] = 'Cuadro de selección (selección individual)';
    //$lang->column_type_list['kr_zip'] = 'zip code (Korean)';
    $lang->column_type_list['date'] = 'fecha (dd/mm/aaaa)';
    //$lang->column_type_list['jp_zip'] = 'zip code (Japanese)';
    $lang->column_name = 'Nombre de la Columna';
    $lang->column_title = 'Título de la Columna';
    $lang->default_value = 'Valor Predefinido';
    $lang->is_active = 'Activado';
    $lang->is_required = 'Espacio requerido';

    // Mensajes de alerta para Javascript usando el filtro XML
    $lang->filter->isnull = 'Ingresar un valor para %s';
    $lang->filter->outofrange = 'Ajustar el largo del texto de %s';
    $lang->filter->equalto = 'Valor de %s es inválido.';
    $lang->filter->invalid_email = 'Formato de %s es inválido. (ej. zbxe@zeroboard.com)';
    $lang->filter->invalid_user_id = $lang->filter->invalid_userid = "Formato de %s es inválido.\\n Todos los valores deberá consistir en alfabetos, números o guión abajo(_) y la primera letra deberá ser en alfabeto Español";
    $lang->filter->invalid_homepage = 'Formato de %s es inválido. (ej: http://www.zeroboard.com)';
    $lang->filter->invalid_korean = 'Formato de %s es inválido. Ingresar ingresar sólo coreano';
    $lang->filter->invalid_korean_number = 'Formato de %s es inválido. Ingresar coreano o números';
    $lang->filter->invalid_alpha = 'Formato de %s es inválido. Ingresar sólo alfabetos';
    $lang->filter->invalid_alpha_number = 'Formato de %s es inválido. Ingresar alfabetos o números';
    $lang->filter->invalid_number = 'Formato de %s es inválido. Ingresar sólo números.';
?>
